import { createRouter, createWebHistory, RouteLocationNormalized } from 'vue-router';
import { enterRoute } from 'bsb-common-web';
import { Role, BaseUrl, Envi } from '@/config/config';
import request from '@/request';
import { store } from '@/store/index';

const router = createRouter({
  history: createWebHistory(BaseUrl),
  routes: [
    {
      path: '/',
      name: 'commonPath',
      component: () => import('../views/frame/Frame.vue'),
      meta: {
        roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
        requireAuth: true
      },
      children: [
        {
          path: '/test',
          name: 'test',
          component: () => import('../views/test/test.vue'),
          meta: {
            roles: [Role.CLERK_ROLE],
            requireAuth: true
          }
        },
        {
          path: '/goods',
          name: 'goods',
          component: () => import('../views/goods/goods.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: '/addGoods',
          name: 'addGoods',
          component: () => import('../views/goods/addGoods.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: 'WarehousingManagement',
          name: 'WarehousingManagement',
          component: () => import('../views/WarehousingManagement/WarehousingManagement.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: 'WarehousingOutStock',
          name: 'WarehousingOutStock',
          component: () => import('../views/WarehousingManagement/WarehousingOutStock.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: 'OutStockDetail',
          name: 'OutStockDetail',
          component: () => import('../views/WarehousingManagement/OutStockDetail.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: 'AddWarehouse',
          name: 'AddWarehouse',
          component: () => import('../views/WarehousingManagement/AddWarehouse.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: 'AddOutStock',
          name: 'AddOutStock',
          component: () => import('../views/WarehousingManagement/AddOutStock.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: 'WareHouseDetail',
          name: 'WareHouseDetail',
          component: () => import('../views/WarehousingManagement/WareHouseDetail.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: 'SupplierManagement',
          name: 'SupplierManagement',
          component: () => import('../views/SupplierManagement/SupplierManagement.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: 'AddSupplier',
          name: 'AddSupplier',
          component: () => import('../views/SupplierManagement/AddSupplier.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: 'EditSupplier',
          name: 'EditSupplier',
          component: () => import('../views/SupplierManagement/EditSupplier.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: 'Page404',
          name: 'Page404',
          component: () => import('../views/Default/Page404.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: 'Page500',
          name: 'Page500',
          component: () => import('../views/Default/Page500.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: '/InventoryFlow',
          name: 'InventoryFlow',
          component: () => import('../views/InventoryManage/InventoryFlow/InventoryFlow.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        },
        {
          path: '/InventoryQuery',
          name: 'InventoryQuery',
          component: () => import('../views/InventoryManage/InventoryQuery/InventoryQuery.vue'),
          meta: {
            roles: [Role.CLERK_ROLE, Role.STORE_ROLE, Role.DEALER],
            requireAuth: true
          }
        }
      ]
    }
  ]
});
router.beforeEach((to: RouteLocationNormalized, from, next) => {
  const authUrl = import.meta.env.VITE_API_BASE_URL; // 跳转的登录页面域名地址
  let redirectUrl = ([Envi.LOCAL_ENV, Envi.MOCK_ENV] as string[]).includes(import.meta.env.MODE)
    ? 'http://localhost:3000/'
    : import.meta.env.VITE_API_BASE_URL;
  redirectUrl += `stock-web`; // 登陆完成回调地址需要后台配置否则认证接口报400
  enterRoute(to, from, next, request, authUrl, redirectUrl, store.state);
});

export default router;
