import { InjectionKey } from 'vue';
import { createStore, useStore as baseUseStore, Store } from 'vuex';
import createPersistedState from 'vuex-persistedstate';
import { user, userState } from './modules/user';

// 公共状态类型约束
export interface State {
  role: string; // 当前角色
  userOrgStation: any;
  userOffice: any;
}

// 将子模块类型导入并且继承父类
interface allTypes extends State {
  user: userState;
}

// 定义 injection key
export const key: InjectionKey<Store<State>> = Symbol('key');

export const store = createStore<State>({
  // 公共状态
  state: {
    role: '',
    userOrgStation: '',
    userOffice: ''
  },
  mutations: {
    setRole(state, payload: string): void {
      state.role = payload;
    },
    setUserOrgStation(state, payload: string): void {
      state.userOrgStation = payload;
    },
    setUserOffice(state, payload: string): void {
      state.userOffice = payload;
    }
  },
  getters: {},
  // 模块状态
  modules: {
    user
  },
  // 持久化
  plugins: [
    createPersistedState({
      key: 'vuexCommon'
    })
  ]
});

export function useStore<T = allTypes>(): Store<T> {
  return baseUseStore<T>(key);
}
