import { defineConfig, loadEnv } from 'vite';
import vue from '@vitejs/plugin-vue';
import VitePluginElementPlus from 'vite-plugin-element-plus';
import { resolve } from 'path';

// https://vitejs.dev/config/
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
export default ({ mode }) => {
  return defineConfig({
    base: './',
    plugins: [vue(), VitePluginElementPlus({})],
    resolve: {
      alias: {
        "@": resolve(__dirname, "src"),
        "@assets": resolve(__dirname, "src/assets"),
        "@components": resolve(__dirname, "src/components"),
        "@images": resolve(__dirname, "src/assets/images"),
        "@views": resolve(__dirname, "src/views"),
        "@store": resolve(__dirname, "src/store"),
      }
    },
    css: {
      preprocessorOptions: {
        scss: {
          additionalData: "@import '@/common/common.scss';"
        }
      }
    },
    build: {
      outDir: "dist",
      // 9月更新
      assetsDir: "assets", //指定静态资源存放路径
      sourcemap: false, //是否构建source map 文件
      terserOptions: {
        // 生产环境移除console
        compress: {
          drop_console: true,
          drop_debugger: true,
        },
      },
    },
    server: {
      proxy: {
        '/api': {
          target: loadEnv(mode, process.cwd()).VITE_API_BASE_URL,
          changeOrigin: true,
          rewrite: (path) => path.replace(/^\/api/, '')
        }
      }
    }
  });
};
